@@ -1,7 +1,7 @@
 // synthv1_config.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2023, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2024, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -42,7 +42,7 @@ synthv1_config *synthv1_config::getInstance (void)
 
 // Constructor.
 synthv1_config::synthv1_config (void)
-	: QSettings(SYNTHV1_DOMAIN, SYNTHV1_TITLE)
+	: QSettings(PROJECT_DOMAIN, PROJECT_NAME)
 {
 	g_pSettings = this;
 
@@ -350,7 +350,7 @@ void synthv1_config::load (void)
 void synthv1_config::save (void)
 {
 	QSettings::beginGroup("/Program");
-	QSettings::setValue("/Version", CONFIG_BUILD_VERSION);
+	QSettings::setValue("/Version", PROJECT_VERSION);
 	QSettings::endGroup();
 
 	QSettings::beginGroup("/Default");
